@@ -260,10 +260,7 @@ class RemittanceContent:
         
         self.reader.move(np.random.randint(len(self.reader)))
 
-        payment_amount = None
-        payment_date = None
-        payment_number = None
-        invoice_numbers = []
+        results = []
         for layout in layouts:
             base_font = self.font.sample()
             
@@ -286,22 +283,47 @@ class RemittanceContent:
                     tb_config['stars_after'] = False
                     amounttextbox = AmountTextBox(tb_config)
                     text_layer, amount = amounttextbox.generate((w, h), font)
+                    
                 elif title in ['Payment amount']:
                     tb_config['stars_before'] = False
                     tb_config['stars_after'] = False
                     amounttextbox = AmountTextBox(tb_config)
-                    text_layer, payment_amount = amounttextbox.generate((w, h), font)
+                    text_layer, text = amounttextbox.generate((w, h), font)
+                    results.append({
+                        'box':text_layer.bbox,
+                        'text':text,
+                        'label':'payment_amount'
+                        })
+                    
                 elif title in ['Invoice amount']:
                     tb_config['stars_before'] = False
                     tb_config['stars_after'] = False
                     amounttextbox = AmountTextBox(tb_config)
-                    text_layer, payment_amount = amounttextbox.generate((w, h), font)
+                    text_layer, text = amounttextbox.generate((w, h), font)
+                    results.append({
+                        'box':text_layer.bbox,
+                        'text':text,
+                        'label':'invoice_amount'
+                        })
+                    
                 elif title in ['Cheque number','Number']:
                     numbertextbox = NumberTextBox(tb_config)
                     text_layer, text = numbertextbox.generate((w, h), font)
+                    results.append({
+                        'box':text_layer.bbox,
+                        'text':text,
+                        'label':'check_number'
+                        })
+                    
                 elif title in ['Payment number']:
                     numbertextbox = NumberTextBox(tb_config)
-                    text_layer, payment_number = numbertextbox.generate((w, h), font)
+                    text_layer, text = numbertextbox.generate((w, h), font)
+                    results.append({
+                        'box':text_layer.bbox,
+                        'text':text,
+                        'label':'payment_number'
+                        })
+                    
                 elif title in ['Address']:
                     addresstextbox = AddressTextBox(tb_config)
                     text_layer, text = addresstextbox.generate((w, h), font)
@@ -313,14 +335,24 @@ class RemittanceContent:
                     text_layer, text = codetextbox.generate((w, h), font)
                 elif title in ['Invoice number']:
                     numbertextbox = NumberTextBox(tb_config)
-                    text_layer, invoice_number = numbertextbox.generate((w, h), font)
-                    invoice_numbers.append(invoice_number)
+                    text_layer, text = numbertextbox.generate((w, h), font)
+                    results.append({
+                        'box':text_layer.bbox,
+                        'text':text,
+                        'label':'invoice_number'
+                        })
                 elif title in ['Date']:
                     datetextbox = DateTextBox(tb_config)
                     text_layer, date_text = datetextbox.generate((w, h), font)
                 elif title in ['Payment date']:
                     datetextbox = DateTextBox(tb_config)
-                    text_layer, payment_date = datetextbox.generate((w, h), font)
+                    text_layer, text = datetextbox.generate((w, h), font)
+                    results.append({
+                        'box':text_layer.bbox,
+                        'text':text,
+                        'label':'payment_date'
+                        })
+                    
                 elif title in ['Amount text']:
                     p = inflect.engine()
                     text =p.number_to_words(amount).replace(',','')
@@ -346,4 +378,4 @@ class RemittanceContent:
 
         self.content_color.apply(text_layers)
 
-        return text_layers, {'payment_date':payment_date,'payment_amount':payment_amount,'payment_number':payment_number,'invoice_numbers':invoice_numbers}
+        return text_layers, results
